@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.7.3
+;; Package-Version: 1.7.4
 ;; Package-Requires: ((emacs "26.1") (compat "30.0.0.0"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -69,11 +69,12 @@
 ;; `no-littering' uses by default, then you have to set the respective
 ;; variables before loading the feature.
 ;;
-;;   (setq no-littering-etc-directory
-;;         (expand-file-name "config/" user-emacs-directory))
-;;   (setq no-littering-var-directory
-;;         (expand-file-name "data/" user-emacs-directory))
-;;   (require 'no-littering)
+;;   (eval-and-compile ; Ensure values don't differ at compile time.
+;;     (setq no-littering-etc-directory
+;;           (expand-file-name "config/" user-emacs-directory))
+;;     (setq no-littering-var-directory
+;;           (expand-file-name "data/" user-emacs-directory))
+;;     (require 'no-littering)
 
 ;; For additional optional settings see "README.org".
 
@@ -305,6 +306,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-caldav-save-directory        (var "org/caldav/save"))
     (setq org-gcal-dir                     (var "org/gcal/"))
     (setq org-journal-cache-file           (var "org/journal-cache.el"))
+    (setq org-node-fakeroam-data-dir       (var "org/node-fakeroam/"))
     (setq org-recent-headings-save-file    (var "org/recent-headings.el"))
     (setq org-registry-file                (var "org/registry.el"))
     (setq org-roam-db-location             (var "org/org-roam.db"))
